# Grai Schemas

Grai Schemas provide reference implementations in Python for objects used in Grai.
So long as your data follows a schema implementation provided in this repository it will be able to interoperate with
all of the other Grai services including the server REST API, yaml serialization, and data integrations.
